import time
import requests
from bs4 import BeautifulSoup
from playwright.sync_api import sync_playwright


def get_suggestions():
    html = requests.get("https://email-fake.com/").text
    soup = BeautifulSoup(html, "html.parser")
    return [child.text for child in soup.find('div', class_="tt-suggestions").children]


def get_message(email: str, timeout: int = 30):
    with sync_playwright() as playwright:
        browser = playwright.firefox.launch(executable_path="C:\\firefox\\firefox.exe")
        context = browser.new_context()
        page = context.new_page()
        start = time.time()
        while time.time() - start < timeout:
            try:
                page.goto(f"https://email-fake.com/{email}")
                return page.inner_html('.mess_bodiyy')
            except Exception as e:
                print(e)



from playwright.sync_api import sync_playwright


def main():
    with sync_playwright() as playwright:
        browser = playwright.firefox.launch()
        context = browser.new_context()
        page = context.new_page()



import time

from names import get_first_name
from requests import JSONDecodeError
import requests
import random
from automation_utilities import Exceptions
from automation_utilities.Generator import generate_email, generate_password, generate_username


def domains():
    return [element['domain'] for element in requests.get('https://api.mail.tm/domains').json()['hydra:member']]


class Account:

    def __init__(
            self,
            name: str | None = None,
            username: str | None = None,
            password: str | None = None,
            username_length: int | None = None,
            password_length: int | None = None
    ):
        self.password = password if password is not None else generate_password(
            password_length if password_length is not None else random.randint(10, 15)
        )
        self.name = name if name is not None else get_first_name()
        self.username = username if username is not None else generate_username(
            get_first_name(), username_length if username_length is not None else random.randint(10, 15)
        )
        self.email_address = generate_email(random.choice(domains()), name, username, username_length)

        data = {
            'address': self.email_address.lower(),
            'password': self.password
        }
        while True:
            try:
                response = requests.post('https://api.mail.tm/accounts', json=data).json()
                self.id = response['id']
                break
            except KeyError:
                raise Exceptions.AccountError()
            except JSONDecodeError:
                pass
        while True:
            try:
                token = requests.post('https://api.mail.tm/token', json=data).json()['token']
                break
            except JSONDecodeError:
                pass
        self.headers = {'Authorization': f"Bearer {token}"}

    def messages(self, timeout: float = 30):
        start = time.time()
        while True:
            while True:
                try:
                    resoponse = requests.get('https://api.mail.tm/messages', headers=self.headers).json()
                    break
                except JSONDecodeError:
                    pass
                if time.time() - start > timeout:
                    raise TimeoutError
            if resoponse['hydra:totalItems'] > 0:
                messages = []
                for member in resoponse['hydra:member']:
                    url = f'https://api.mail.tm/messages/{member["id"]}'
                    while True:
                        try:
                            messages.append(requests.get(url, headers=self.headers).json()['html'])
                            break
                        except JSONDecodeError:
                            pass
                if resoponse['hydra:totalItems'] == 1:
                    return messages[0][0]
                else:
                    return messages[0]
            if time.time() - start > timeout:
                raise TimeoutError



from uuid import getnode
from art import text2art
from colorama import Fore


def intro(name: str):
    print(f'{Fore.LIGHTYELLOW_EX}{text2art("Hazem3010", "alligator")}')
    indent = '\t'*15
    print(f'{Fore.GREEN}{indent}{name}\t{Fore.LIGHTMAGENTA_EX}::\t{Fore.CYAN}Your ID: {getnode()}')


intro("Test")



import requests
from bs4 import BeautifulSoup
from playwright.sync_api import sync_playwright


# class Child:
#     def __init__(self, child_id, child_name):
#         self.id = child_id
#         self.name = child_name


class File:
    def __init__(self, file_id: str, file_name: str):
        self.id = file_id
        self.name = file_name

    def content(self):
        html = requests.get(f"https://www.mediafire.com/file/{self.id}/{self.name}").text
        soup = BeautifulSoup(html, 'html.parser')
        url = soup.find('a', attrs={'aria-label': "Download file"}).get('href')
        return requests.get(url).text


class Folder:
    def __init__(self, folder_id: str):
        self.children = []
        with sync_playwright() as playwright:
            page = playwright.firefox.launch(executable_path='c:/firefox/firefox.exe').new_page()
            page.goto(f'https://www.mediafire.com/folder/{folder_id}', wait_until='commit')
            while True:
                try:
                    list_items = page.query_selector('#main_list').query_selector_all('li')
                    if len(list_items) == 0:
                        continue
                    for item in list_items:
                        file_id = item.get_attribute('id').split('-')[1].strip()
                        file_name = item.query_selector('a.foldername').text_content().strip()
                        self.children.append(File(file_id, file_name))
                    break
                except AttributeError:
                    pass


for file in Folder('hcy8vshstj1mp').children:
    if file.name == 'users.txt':
        print(file.content())



import random
import string
from names import get_first_name


def generate_username(name: str = get_first_name(), length: int = random.randint(10, 15)):
    return f'{name}{"".join(random.choice(string.digits) for _ in range(length - len(name)))}'.lower()


def generate_email(
        domain: str,
        name: str | None = None,
        username: str | None = None,
        username_length: int | None = None
):
    if username is None:
        username = generate_username(
            name if name is not None else get_first_name(),
            username_length if username_length is not None else random.randint(10, 15)
        )
    return f'{username}@{domain}'


def generate_password(length: int = random.randint(10, 20)):
    return ''.join(random.choice(string.ascii_letters + string.digits) for _ in range(length))



import bs4
import names
import phonenumbers
import playwright
import requests
import setuptools
from setuptools import setup, find_packages

setup(
    name='automation_utilities',
    version='1.5.1',
    packages=find_packages(),
)

install_requires = [requests, setuptools, bs4, playwright, names, phonenumbers]
